@@ -1,10 +1,11 @@
 mod action;
 mod client;
 mod error;
+mod pagination;
+
 mod request {
   mod login;
   mod session;
-
   pub use login::Login;
 }
 mod response {
@@ -23,8 +24,8 @@ mod response {
 
 pub use action::{Action, ShowWorkflowMode};
 pub use client::Client;
-
 pub use error::{Error, Result};
+pub use pagination::Pagination;
 pub use request::Login;
 pub use response::{
   AccessToken, CredentialList, CredentialShow, UserList, UserShow, WorkerList, WorkerShow,
